@@ -115,6 +115,10 @@ class TestRecipe(unittest.TestCase):
         # The command method is a wrapper for subprocess which excutes
         # a command and return's it's status code. We will demonstrate
         # this with a simple test of running `dir`.
+        import sys
+        import StringIO
+        stdout = StringIO.StringIO()
+        sys.stdout = stdout
         self.failIf(self.recipe.command('echo'))
         # Executing a non existing command should return an error code
         self.assert_(self.recipe.command('spamspamspameggs'))
